@@ -1,12 +1,14 @@
 package Test::WWW::Mechanize::PSGI;
+$Test::WWW::Mechanize::PSGI::VERSION = '0.35';
 use strict;
 use warnings;
+
 use Carp;
 use HTTP::Message::PSGI;
 use Test::WWW::Mechanize;
 use Try::Tiny;
+
 use base 'Test::WWW::Mechanize';
-our $VERSION = '0.34';
 
 my $Test = Test::Builder->new();
 
@@ -26,15 +28,16 @@ sub new {
     return $self;
 }
 
-sub _make_request {
+sub simple_request {
     my ( $self, $request ) = @_;
 
+    $self->run_handlers( "request_send", $request );
+
     my $uri = $request->uri;
     $uri->scheme('http')    unless defined $uri->scheme;
     $uri->host('localhost') unless defined $uri->host;
-    $self->cookie_jar->add_cookie_header($request) if $self->cookie_jar;
 
-    my $env = $request->to_psgi;
+    my $env = $self->prepare_request($request)->to_psgi;
     my $response;
     try {
         $response = HTTP::Response->from_psgi( $self->{app}->($env) );
@@ -46,18 +49,24 @@ sub _make_request {
         $response->content_type('');
     };
     $response->request($request);
-    $self->cookie_jar->extract_cookies($response) if $self->cookie_jar;
+    $self->run_handlers( "response_done", $response );
     return $response;
 }
 
 1;
 
-__END__
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Test::WWW::Mechanize::PSGI - Test PSGI programs using WWW::Mechanize
 
+=head1 VERSION
+
+version 0.35
+
 =head1 SYNOPSIS
 
   # We're in a t/*.t test script...
@@ -79,7 +88,7 @@ Test::WWW::Mechanize::PSGI - Test PSGI programs using WWW::Mechanize
   $mech->title_is('Hi');
   $mech->content_contains('Hello World');
   # ... and all other Test::WWW::Mechanize methods
-  
+
 =head1 DESCRIPTION
 
 L<PSGI> is a specification to decouple web server environments from
@@ -172,7 +181,13 @@ I<%parms> is a hashref containing the parms to pass to C<submit_form()>.
 Note that the parms to C<submit_form()> are a hash whereas the parms to
 this function are a hashref.  You have to call this function like:
 
-    $agent->submit_form_ok( {n=>3}, "looking for 3rd link" );
+    $agent->submit_form_ok(
+        form_number => 3,
+        fields      => {
+            username    => 'mungo',
+            password    => 'lost-and-alone',
+        }
+    }, "looking for 3rd form" );
 
 As with other test functions, C<$desc> is optional.  If it is supplied
 then it will display when running the test harness in verbose mode.
@@ -411,14 +426,18 @@ of any maxlength specified in the HTML).
 
 =head1 AUTHOR
 
-Leon Brocard <acme@astray.com>.
+Leon Brocard <acme@astray.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, Leon Brocard
+This software is copyright (c) 2009 by Leon Brocard.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This module is free software; you can redistribute it or modify it
-under the same terms as Perl itself.
+=cut
+
+__END__
+
+# ABSTRACT: Test PSGI programs using WWW::Mechanize
 
